# ETH Pydantic Types Documentation

```{eval-rst}
.. toctree::
   :caption: User Guides
   :maxdepth: 1

   userguides/quickstart
```

```{eval-rst}
.. toctree::
   :caption: Python Reference
   :maxdepth: 1

   methoddocs/address.md
   methoddocs/hash.md  
   methoddocs/hexbytes.md
```
